VerifiedBounds

Struct VerifiedBounds 

pub struct VerifiedBounds { /* private fields */ }
Verified bounds.

This structure contains the original set of parameters – the grant, verify mode, and verified components – used when verifying bounds in BoundsVerifier::verify. It can then be used to feed into additional components, such as MemoryPartitioner, to ensure that the same parameters are used, avoiding any potential misconfiguration.

Implementations

Source

impl VerifiedBounds

pub fn total_available_bytes(&self) -> usize

Total number of bytes available for allocation.

pub fn total_minimum_required_bytes(&self) -> usize

Returns the total number of minimum required bytes for all components that were verified.

pub fn total_firm_limit_bytes(&self) -> usize

Returns the total firm limit, in bytes, for all components that were verified.

pub fn bounds(&self) -> &ComponentBounds

Gets a reference to the original component bounds that were verified.